% bruceABME_fig3  Run simulations and plot results corresponding to
%                 Figure 3 from:
%
%                 Bruce, I. C. (2007). "Implementation issues in
%                 approximate methods for stochastic HodgkinHuxley
%                 models," Annals of Biomedical Engineering 35(2):315318.
%
% Ian C. Bruce (ibruce@ieee.org)  2007

figure

% Create vector of bin edges in units of millisecond for spike latency
% histograms
edges = 0:1e-2:1.5;

% Simulate and plot 10 responses of the Chow & White model to the
% preconditioned pulse
for lp = 1:10
    
    [V,N_Na,Istim,t] = stochasticHH('cw',[2.5 3.5]/0.265);
    subplot(3,2,1)
    plot(t,V,'k-')
    hold on

end
axis([-0.02 1.2 0 150])
title('Chow & White')

% Calculate spike statistics for 1000 responses of the Chow & White model
% to the preconditioned pulse and plot a histogram of spike latencies
[FE,meanlt,jitter,lt]=APstats('cw',[2.5 3.5]/0.265,1e3);
n = histc(lt,edges);
subplot(3,2,2)
sphist2 = bar(edges,n,'histc');
set(sphist2,'edgecolor','k','facecolor','k')
axis([-0.02 1.2 0 200])
title('Chow & White')
text(0.82,150,{['FE = ' num2str(FE,'%4.3f')], ['JT = ' num2str(jitter,'%4.3f')], ['LT = ' num2str(meanlt,'%4.3f')]})

% Simulate and plot 10 responses of the Fox model with floor(N_Na) to the
% preconditioned pulse
for lp = 1:10
    
    [V,N_Na,Istim,t] = stochasticHH('fxfloor',[2.5 3.5]/0.265);
    subplot(3,2,3)
    plot(t,V,'k-')
    hold on

end
axis([-0.02 1.2 0 150])
ylabel('Transmembrane potential [mV]')
title('Fox - \lfloorN_{Na}\rfloor')

% Calculate spike statistics for 1000 responses of the Fox model with
% floor(N_Na) to the preconditioned pulse and plot a histogram of spike
% latencies
[FE,meanlt,jitter,lt]=APstats('fxfloor',[2.5 3.5]/0.265,1e3);
n = histc(lt,edges);
subplot(3,2,4)
sphist2 = bar(edges,n,'histc');
set(sphist2,'edgecolor','k','facecolor','k')
axis([-0.02 1.2 0 200])
ylabel('# of spikes')
title('Fox - \lfloorN_{Na}\rfloor')
text(0.82,150,{['FE = ' num2str(FE,'%4.3f')], ['JT = ' num2str(jitter,'%4.3f')], ['LT = ' num2str(meanlt,'%4.3f')]})

% Simulate and plot 10 responses of the Fox model with nint(N_Na) to the
% preconditioned pulse
for lp = 1:10
    
    [V,N_Na,Istim,t] = stochasticHH('fxnint',[2.5 3.5]/0.265);
    subplot(3,2,5)
    plot(t,V,'k-')
    hold on

end

axis([-0.02 1.2 0 150])
xlabel('Time [ms]')
title('Fox - nint(N_{Na})')

% Calculate spike statistics for 1000 responses of the Fox model with
% nint(N_Na) to the preconditioned pulse and plot a histogram of spike
% latencies
[FE,meanlt,jitter,lt]=APstats('fxnint',[2.5 3.5]/0.265,1e3);
n = histc(lt,edges);
subplot(3,2,6)
sphist3 = bar(edges,n,'histc');
set(sphist3,'edgecolor','k','facecolor','k')
axis([-0.02 1.2 0 200])
title('Fox - nint(N_{Na})')
xlabel('Time [ms]')
text(0.82,150,{['FE = ' num2str(FE,'%4.3f')], ['JT = ' num2str(jitter,'%4.3f')], ['LT = ' num2str(meanlt,'%4.3f')]})
